@@ -1,34 +1,34 @@
 #!/usr/bin/env bash
 
 #############################################################################
-## 
+##
 ##   This script creates a JIProlog logtalk.jip file with the Logtalk
 ##   compiler and runtime and optionally an application.jip file with
 ##   a Logtalk application
-## 
-##   Last updated on January 30, 2025
-## 
-##   This file is part of Logtalk <https://logtalk.org/>  
+##
+##   Last updated on March 23, 2025
+##
+##   This file is part of Logtalk <https://logtalk.org/>
 ##   SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>
 ##   SPDX-License-Identifier: Apache-2.0
-##   
+##
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
 ##   You may obtain a copy of the License at
-##   
+##
 ##       http://www.apache.org/licenses/LICENSE-2.0
-##   
+##
 ##   Unless required by applicable law or agreed to in writing, software
 ##   distributed under the License is distributed on an "AS IS" BASIS,
 ##   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ##   See the License for the specific language governing permissions and
 ##   limitations under the License.
-## 
+##
 #############################################################################
 
 
 print_version() {
-	echo "$(basename "$0") 0.20"
+	echo "$(basename "$0") 0.21"
 	exit 0
 }
 
@@ -105,9 +105,8 @@ paths="$LOGTALKHOME/paths/paths.pl"
 settings="$LOGTALKHOME/scripts/embedding/settings-embedding-sample.lgt"
 compile="false"
 
-usage_help()
-{
-	echo 
+usage_help() {
+	echo
 	echo "This script creates a JIProlog logtalk.jip file with the Logtalk compiler and"
 	echo "runtime and an optional application.jip file from an application source code"
 	echo "given its loader file."
@@ -129,8 +128,7 @@ usage_help()
 	echo
 }
 
-while getopts "cd:t:p:l:s:vh" option
-do
+while getopts "cd:t:p:l:s:vh" option; do
 	case $option in
 		c) compile="true";;
 		d) d_arg="$OPTARG";;
@@ -139,8 +137,8 @@ do
 		s) s_arg="$OPTARG";;
 		l) l_arg="$OPTARG";;
 		v) print_version;;
-		h) usage_help; exit;;
-		*) usage_help; exit;;
+		h) usage_help; exit 0;;
+		*) usage_help; exit 1;;
 	esac
 done
 
